Text

Struct Text 

pub struct Text {
    pub lines: Vec<Line>,
}
Multi-line styled text.

Fields

lines: Vec<Line>

Implementations

Source

impl Text

pub fn new(lines: impl IntoIterator<Item = Line>) -> Self

pub fn height(&self) -> usize

Number of lines.

pub fn max_width(&self) -> u16

Maximum width among all lines.

pub fn first_text(&self) -> &str

The text of the first span of the first line, or “” if empty.

pub fn render(&self, buf: &mut Buffer, rect: Rect) -> Size

Write all lines to the buffer within the given rect. Returns the actual size used.