pub struct Checkbox { /* private fields */ }Expand description
A checkbox widget with a label and toggleable state.
Press Space or Enter to toggle. Renders as [✓] label when checked
and [ ] label when unchecked.
Implementations
Sourceimpl Checkbox
impl Checkbox
Sourcepub fn new(label: impl Into<Text>) -> Self
pub fn new(label: impl Into<Text>) -> Self
Creates a new unchecked checkbox with the given label.
Sourcepub fn checked_style(self, style: Style) -> Self
pub fn checked_style(self, style: Style) -> Self
Builder: sets the checked-state style.
Sourcepub fn is_checked(&self) -> bool
pub fn is_checked(&self) -> bool
Returns whether the checkbox is currently checked.
Sourcepub fn set_checked(&mut self, checked: bool, cx: &mut EventCx<'_>)
pub fn set_checked(&mut self, checked: bool, cx: &mut EventCx<'_>)
Sets the checked state.